## Summary Table

| Story Id | Title | Links |
| --------- | ----- | ----- |
| transformer-rec | Transformer-based Recommenders | <a href="https://recohut-projects.github.io/transformer-rec" alt=""> <img src="https://img.shields.io/static/v1?label=report&message=active&color=green" /></a><a href="https://github.com/RecoHut-Projects/transformer-rec" alt=""> <img src="https://img.shields.io/static/v1?label=code&message=github&color=blue" /></a> |
| drl-recsys | Deep Reinforcement Learning in Recommender Systems | <a href="https://recohut-projects.github.io/drl-recsys" alt=""> <img src="https://img.shields.io/static/v1?label=report&message=active&color=green" /></a><a href="https://github.com/RecoHut-Projects/drl-recsys" alt=""> <img src="https://img.shields.io/static/v1?label=code&message=github&color=blue" /></a> |
| sessrec-gnn | Session-based Recommendation with Graph Neural Networks | <a href="https://htmlpreview.github.io/?https://github.com/RecoHut-Projects/sessrec-gnn/blob/main/report/sessionrec_gnn_report.html" alt=""> <img src="https://img.shields.io/static/v1?label=report&message=active&color=green" /></a><a href="" alt="https://github.com/RecoHut-Projects/sessrec-gnn"> <img src="https://img.shields.io/static/v1?label=code&message=github&color=blue" /></a> |
| ope-rec | Off-policy Evaluation in Recommender Systems | <a href="https://recohut-projects.github.io/ope-rec" alt=""> <img src="https://img.shields.io/static/v1?label=report&message=active&color=green" /></a><a href="https://github.com/RecoHut-Projects/ope-rec" alt=""> <img src="https://img.shields.io/static/v1?label=code&message=github&color=blue" /></a> |
| incremental-learning | Model Retraining & Incremental Learning in Recommender Systems | <a href="https://recohut-projects.github.io/incremental-learning" alt=""> <img src="https://img.shields.io/static/v1?label=report&message=active&color=green" /></a><a href="https://github.com/RecoHut-Projects/incremental-learning" alt=""> <img src="https://img.shields.io/static/v1?label=code&message=github&color=blue" /></a> |
| multiobjective-optimizations | Multi-Objective Optimizations in Recommender Systems | <a href="https://recohut-projects.github.io/multiobjective-optimizations/" alt=""> <img src="https://img.shields.io/static/v1?label=report&message=active&color=green" /></a><a href="https://github.com/RecoHut-Projects/multiobjective-optimizations" alt=""> <img src="https://img.shields.io/static/v1?label=code&message=github&color=blue" /></a> |
| coldstart-recsys | Proving Recommendations in case of Cold-start situations | <a href="https://recohut-projects.github.io/coldstart-recsys" alt=""> <img src="https://img.shields.io/static/v1?label=report&message=active&color=green" /></a><a href="https://github.com/RecoHut-Projects/coldstart-recsys" alt=""> <img src="https://img.shields.io/static/v1?label=code&message=github&color=blue" /></a> |
| recsys-attacks | Attacks on Recommender Systems | <a href="https://recohut-projects.github.io/recsys-attacks" alt=""> <img src="https://img.shields.io/static/v1?label=report&message=active&color=green" /></a><a href="https://github.com/RecoHut-Projects/recsys-attacks" alt=""> <img src="https://img.shields.io/static/v1?label=code&message=github&color=blue" /></a> |
| graph-embeddings | Graph Embeddings | <a href="https://recohut-projects.github.io/graph-embeddings" alt=""> <img src="https://img.shields.io/static/v1?label=report&message=active&color=green" /></a><a href="https://github.com/RecoHut-Projects/graph-embeddings" alt=""> <img src="https://img.shields.io/static/v1?label=code&message=github&color=blue" /></a> |

## Sites
| Site | Title | Links |
| --------- | ----- | ----- |
| reconb | 200+ Jupyter Notebooks on Recommender Systems | <a href="https://nb.recohut.com/" alt="reconb"> <img src="https://img.shields.io/static/v1?label=site&message=active&color=green" /></a><a href="https://github.com/RecoHut-Projects/notebooks" alt="reconb"> <img src="https://img.shields.io/static/v1?label=backend&message=github&color=blue" /></a> |
| recostep | Collection of Recsys Tutorials and Stories | <a href="https://step.recohut.com/" alt="recostep"> <img src="https://img.shields.io/static/v1?label=site&message=active&color=green" /></a><a href="https://github.com/recohut/reco-step" alt="recostep"> <img src="https://img.shields.io/static/v1?label=backend&message=github&color=blue" /></a> |
